==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/cohort_pool_components.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.cohort_pool_component import CohortPoolComponent
from ..types import UNSET, Unset

T = TypeVar("T", bound="CohortPoolComponents")


@attr.s(auto_attribs=True)
class CohortPoolComponents:
    """  """

    components: Union[Unset, List[CohortPoolComponent]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        components: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.components, Unset):
            components = []
            for components_item_data in self.components:
                components_item = components_item_data.to_dict()

                components.append(components_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if components is not UNSET:
            field_dict["components"] = components

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        components = []
        _components = d.pop("components", UNSET)
        for components_item_data in _components or []:
            components_item = CohortPoolComponent.from_dict(components_item_data)

            components.append(components_item)

        cohort_pool_components = cls(
            components=components,
        )

        cohort_pool_components.additional_properties = d
        return cohort_pool_components

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/cohort_pool_components.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_component import PoolComponent
from ..types import UNSET, Unset

T = TypeVar("T", bound="CohortPoolComponents")


@attr.s(auto_attribs=True)
class CohortPoolComponents:
    """  """

    components: Union[Unset, List[PoolComponent]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        components: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.components, Unset):
            components = []
            for components_item_data in self.components:
                components_item = components_item_data.to_dict()

                components.append(components_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if components is not UNSET:
            field_dict["components"] = components

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        components = []
        _components = d.pop("components", UNSET)
        for components_item_data in _components or []:
            components_item = PoolComponent.from_dict(components_item_data)

            components.append(components_item)

        cohort_pool_components = cls(
            components=components,
        )

        cohort_pool_components.additional_properties = d
        return cohort_pool_components

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
